##  Commenting on Fact Sheets
The commenting feature on fact sheets allows you to post comments on the fact sheets. Keeping the discussions within the fact sheet simplifies collaboration and reduces the need for excessive email communication.
You can propose updates and seek clarifications without making direct changes to the fact sheet itself. When a comment is posted, it triggers notifications to the responsible subscribers. You can change your notification settings to disable notifications. To learn more, see [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod7a909a5382b4b5b993e4d06b4c60856_LowRes.png)
Commenting on Fact Sheets
